@@ -31,14 +31,13 @@ import re
 import sys
 import unittest
 
-import warnings
-
 import numpy as np
 
 from glymur import Jp2k
 import glymur
 
 from .fixtures import OPJ_DATA_ROOT
+from .fixtures import WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG
 from .fixtures import mse, peak_tolerance, read_pgx, opj_data_file
 
 
@@ -56,11 +55,11 @@ class TestSuite2point1(unittest.TestCase):
     def tearDown(self):
         pass
 
+    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_NR_DEC_text_GBR_jp2_29_decode(self):
         jfile = opj_data_file('input/nonregression/text_GBR.jp2')
-        with warnings.catch_warnings():
+        with self.assertWarns(UserWarning):
             # brand is 'jp2 ', but has any icc profile.
-            warnings.simplefilter("ignore")
             jp2 = Jp2k(jfile)
         jp2.read()
         self.assertTrue(True)
@@ -85,32 +84,32 @@ class TestSuite2point1(unittest.TestCase):
         Jp2k(jfile).read()
         self.assertTrue(True)
 
+    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_NR_DEC_gdal_fuzzer_unchecked_num_resolutions_jp2_36_decode(self):
         f = 'input/nonregression/gdal_fuzzer_unchecked_numresolutions.jp2'
         jfile = opj_data_file(f)
-        with warnings.catch_warnings():
+        with self.assertWarns(UserWarning):
             # Invalid number of resolutions.
-            warnings.simplefilter("ignore")
             j = Jp2k(jfile)
             with self.assertRaises(IOError):
                 j.read()
 
+    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_NR_DEC_gdal_fuzzer_check_number_of_tiles_jp2_38_decode(self):
         relpath = 'input/nonregression/gdal_fuzzer_check_number_of_tiles.jp2'
         jfile = opj_data_file(relpath)
-        with warnings.catch_warnings():
+        with self.assertWarns(UserWarning):
             # Invalid number of tiles.
-            warnings.simplefilter("ignore")
             j = Jp2k(jfile)
             with self.assertRaises(IOError):
                 j.read()
 
+    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_NR_DEC_gdal_fuzzer_check_comp_dx_dy_jp2_39_decode(self):
         relpath = 'input/nonregression/gdal_fuzzer_check_comp_dx_dy.jp2'
         jfile = opj_data_file(relpath)
-        with warnings.catch_warnings():
+        with self.assertWarns(UserWarning):
             # Invalid subsampling value
-            warnings.simplefilter("ignore")
             with self.assertRaises(IOError):
                 Jp2k(jfile).read()
 
@@ -124,105 +123,6 @@ class TestSuite2point1(unittest.TestCase):
         Jp2k(jfile).read()
         self.assertTrue(True)
 
-    def test_NR_DEC_p1_04_j2k_43_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(0, 0, 1024, 1024))
-        odata = jp2k.read()
-        np.testing.assert_array_equal(ssdata, odata)
-
-    def test_NR_DEC_p1_04_j2k_44_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(640, 512, 768, 640))
-        odata = jp2k.read()
-        np.testing.assert_array_equal(ssdata, odata[640:768, 512:640])
-
-    def test_NR_DEC_p1_04_j2k_45_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(896, 896, 1024, 1024))
-        odata = jp2k.read()
-        np.testing.assert_array_equal(ssdata, odata[896:1024, 896:1024])
-
-    def test_NR_DEC_p1_04_j2k_46_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(500, 100, 800, 300))
-        odata = jp2k.read()
-        np.testing.assert_array_equal(ssdata, odata[500:800, 100:300])
-
-    def test_NR_DEC_p1_04_j2k_47_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(520, 260, 600, 360))
-        odata = jp2k.read()
-        np.testing.assert_array_equal(ssdata, odata[520:600, 260:360])
-
-    def test_NR_DEC_p1_04_j2k_48_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(520, 260, 660, 360))
-        odata = jp2k.read()
-        np.testing.assert_array_equal(ssdata, odata[520:660, 260:360])
-
-    def test_NR_DEC_p1_04_j2k_49_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(520, 360, 600, 400))
-        odata = jp2k.read()
-        np.testing.assert_array_equal(ssdata, odata[520:600, 360:400])
-
-    def test_NR_DEC_p1_04_j2k_50_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(0, 0, 1024, 1024), rlevel=2)
-        odata = jp2k.read(rlevel=2)
-
-        np.testing.assert_array_equal(ssdata, odata[0:256, 0:256])
-
-    def test_NR_DEC_p1_04_j2k_51_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(640, 512, 768, 640), rlevel=2)
-        odata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(ssdata, odata[160:192, 128:160])
-
-    def test_NR_DEC_p1_04_j2k_52_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(896, 896, 1024, 1024), rlevel=2)
-        odata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(ssdata, odata[224:352, 224:352])
-
-    def test_NR_DEC_p1_04_j2k_53_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(500, 100, 800, 300), rlevel=2)
-        odata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(ssdata, odata[125:200, 25:75])
-
-    def test_NR_DEC_p1_04_j2k_54_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(520, 260, 600, 360), rlevel=2)
-        odata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(ssdata, odata[130:150, 65:90])
-
-    def test_NR_DEC_p1_04_j2k_55_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(520, 260, 660, 360), rlevel=2)
-        odata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(ssdata, odata[130:165, 65:90])
-
-    def test_NR_DEC_p1_04_j2k_56_decode(self):
-        jfile = opj_data_file('input/conformance/p1_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(520, 360, 600, 400), rlevel=2)
-        odata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(ssdata, odata[130:150, 90:100])
-
     def test_NR_DEC_p1_04_j2k_57_decode(self):
         jfile = opj_data_file('input/conformance/p1_04.j2k')
         jp2k = Jp2k(jfile)
@@ -251,139 +151,192 @@ class TestSuite2point1(unittest.TestCase):
         odata = jp2k.read(rlevel=1)
         np.testing.assert_array_equal(tdata, odata[64:128, 256:320])
 
+    @unittest.skipIf(WARNING_INFRASTRUCTURE_ISSUE, WARNING_INFRASTRUCTURE_MSG)
     def test_NR_DEC_jp2_36_decode(self):
         lst = ('input',
                'nonregression',
                'gdal_fuzzer_assert_in_opj_j2k_read_SQcd_SQcc.patch.jp2')
         jfile = opj_data_file('/'.join(lst))
-        with warnings.catch_warnings():
+        with self.assertWarns(UserWarning):
             # Invalid component number.
-            warnings.simplefilter("ignore")
             j = Jp2k(jfile)
             with self.assertRaises(IOError):
                 j.read()
 
-    def test_NR_DEC_p1_06_j2k_70_decode(self):
+@unittest.skipIf(OPJ_DATA_ROOT is None,
+                 "OPJ_DATA_ROOT environment variable not set")
+@unittest.skipIf(re.match(r'''(1|2.0.0)''',
+                          glymur.version.openjpeg_version) is not None,
+                 "Only supported in 2.0.1 or higher")
+class TestReadArea(unittest.TestCase):
+    """
+    Runs tests introduced in version 2.0+ or that pass only in 2.0+
+    
+    Specifically for read method with area parameter.
+    """
+    @classmethod
+    def setUpClass(self):
+
+        jfile = opj_data_file('input/conformance/p1_04.j2k')
+        self.j2k = Jp2k(jfile)
+        self.j2k_data = self.j2k.read()
+        self.j2k_half_data = self.j2k.read(rlevel=1)
+        self.j2k_quarter_data = self.j2k.read(rlevel=2)
+
         jfile = opj_data_file('input/conformance/p1_06.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(9, 9, 12, 12), rlevel=1)
-        self.assertEqual(ssdata.shape, (1, 1, 3))
+        self.j2k_p1_06 = Jp2k(jfile)
+
+    def test_NR_DEC_p1_04_j2k_43_decode(self):
+        actual = self.j2k.read(area=(0, 0, 1024, 1024))
+        expected = self.j2k_data
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_44_decode(self):
+        actual = self.j2k.read(area=(640, 512, 768, 640))
+        expected = self.j2k_data[640:768, 512:640]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_45_decode(self):
+        actual = self.j2k.read(area=(896, 896, 1024, 1024))
+        expected = self.j2k_data[896:1024, 896:1024]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_46_decode(self):
+        actual = self.j2k.read(area=(500, 100, 800, 300))
+        expected = self.j2k_data[500:800, 100:300]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_47_decode(self):
+        actual = self.j2k.read(area=(520, 260, 600, 360))
+        expected = self.j2k_data[520:600, 260:360]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_48_decode(self):
+        actual = self.j2k.read(area=(520, 260, 660, 360))
+        expected = self.j2k_data[520:660, 260:360]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_49_decode(self):
+        actual = self.j2k.read(area=(520, 360, 600, 400))
+        expected = self.j2k_data[520:600, 360:400]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_50_decode(self):
+        actual = self.j2k.read(area=(0, 0, 1024, 1024), rlevel=2)
+        expected = self.j2k_quarter_data
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_51_decode(self):
+        actual = self.j2k.read(area=(640, 512, 768, 640), rlevel=2)
+        expected = self.j2k_quarter_data[160:192, 128:160]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_52_decode(self):
+        actual = self.j2k.read(area=(896, 896, 1024, 1024), rlevel=2)
+        expected = self.j2k_quarter_data[224:352, 224:352]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_53_decode(self):
+        actual = self.j2k.read(area=(500, 100, 800, 300), rlevel=2)
+        expected = self.j2k_quarter_data[125:200, 25:75]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_54_decode(self):
+        actual = self.j2k.read(area=(520, 260, 600, 360), rlevel=2)
+        expected = self.j2k_quarter_data[130:150, 65:90]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_55_decode(self):
+        actual = self.j2k.read(area=(520, 260, 660, 360), rlevel=2)
+        expected = self.j2k_quarter_data[130:165, 65:90]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_04_j2k_56_decode(self):
+        actual = self.j2k.read(area=(520, 360, 600, 400), rlevel=2)
+        expected = self.j2k_quarter_data[130:150, 90:100]
+        np.testing.assert_array_equal(actual, expected)
+
+    def test_NR_DEC_p1_06_j2k_70_decode(self):
+        actual = self.j2k_p1_06.read(area=(9, 9, 12, 12), rlevel=1)
+        self.assertEqual(actual.shape, (1, 1, 3))
 
     def test_NR_DEC_p1_06_j2k_71_decode(self):
-        jfile = opj_data_file('input/conformance/p1_06.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(10, 4, 12, 10), rlevel=1)
-        self.assertEqual(ssdata.shape, (1, 3, 3))
+        actual = self.j2k_p1_06.read(area=(10, 4, 12, 10), rlevel=1)
+        self.assertEqual(actual.shape, (1, 3, 3))
 
     def test_NR_DEC_p1_06_j2k_72_decode(self):
-        jfile = opj_data_file('input/conformance/p1_06.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(3, 3, 9, 9), rlevel=1)
+        ssdata = self.j2k_p1_06.read(area=(3, 3, 9, 9), rlevel=1)
         self.assertEqual(ssdata.shape, (3, 3, 3))
 
     def test_NR_DEC_p1_06_j2k_73_decode(self):
-        jfile = opj_data_file('input/conformance/p1_06.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(4, 4, 7, 7), rlevel=1)
+        ssdata = self.j2k_p1_06.read(area=(4, 4, 7, 7), rlevel=1)
         self.assertEqual(ssdata.shape, (2, 2, 3))
 
     def test_NR_DEC_p1_06_j2k_74_decode(self):
-        jfile = opj_data_file('input/conformance/p1_06.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(4, 4, 5, 5), rlevel=1)
+        ssdata = self.j2k_p1_06.read(area=(4, 4, 5, 5), rlevel=1)
         self.assertEqual(ssdata.shape, (1, 1, 3))
 
     def test_NR_DEC_p1_06_j2k_75_decode(self):
         # Image size would be 0 x 0.
-        jfile = opj_data_file('input/conformance/p1_06.j2k')
-        jp2k = Jp2k(jfile)
         with self.assertRaises((IOError, OSError)):
-            jp2k.read(area=(9, 9, 12, 12), rlevel=2)
+            self.j2k_p1_06.read(area=(9, 9, 12, 12), rlevel=2)
 
     def test_NR_DEC_p0_04_j2k_85_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(0, 0, 256, 256))
-        fulldata = jp2k.read()
-        np.testing.assert_array_equal(fulldata[0:256, 0:256], ssdata)
+        actual = self.j2k.read(area=(0, 0, 256, 256))
+        expected = self.j2k_data[:256, :256]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_86_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(0, 128, 128, 256))
-        fulldata = jp2k.read()
-        np.testing.assert_array_equal(fulldata[0:128, 128:256], ssdata)
+        actual = self.j2k.read(area=(0, 128, 128, 256))
+        expected = self.j2k_data[:128, 128:256]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_87_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(10, 50, 200, 120))
-        fulldata = jp2k.read()
-        np.testing.assert_array_equal(fulldata[10:200, 50:120], ssdata)
+        actual = self.j2k.read(area=(10, 50, 200, 120))
+        expected = self.j2k_data[10:200, 50:120]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_88_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(150, 10, 210, 190))
-        fulldata = jp2k.read()
-        np.testing.assert_array_equal(fulldata[150:210, 10:190], ssdata)
+        actual = self.j2k.read(area=(150, 10, 210, 190))
+        expected = self.j2k_data[150:210, 10:190]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_89_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(80, 100, 150, 200))
-        fulldata = jp2k.read()
-        np.testing.assert_array_equal(fulldata[80:150, 100:200], ssdata)
+        actual = self.j2k.read(area=(80, 100, 150, 200))
+        expected = self.j2k_data[80:150, 100:200]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_90_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(20, 150, 50, 200))
-        fulldata = jp2k.read()
-        np.testing.assert_array_equal(fulldata[20:50, 150:200], ssdata)
+        actual = self.j2k.read(area=(20, 150, 50, 200))
+        expected = self.j2k_data[20:50, 150:200]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_91_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(0, 0, 256, 256), rlevel=2)
-        fulldata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(fulldata[0:64, 0:64], ssdata)
+        actual = self.j2k.read(area=(0, 0, 256, 256), rlevel=2)
+        expected = self.j2k_quarter_data[0:64, 0:64]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_92_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(0, 128, 128, 256), rlevel=2)
-        fulldata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(fulldata[0:32, 32:64], ssdata)
+        actual = self.j2k.read(area=(0, 128, 128, 256), rlevel=2)
+        expected = self.j2k_quarter_data[:32, 32:64]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_93_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(10, 50, 200, 120), rlevel=2)
-        fulldata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(fulldata[3:50, 13:30], ssdata)
+        actual = self.j2k.read(area=(10, 50, 200, 120), rlevel=2)
+        expected = self.j2k_quarter_data[3:50, 13:30]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_94_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(150, 10, 210, 190), rlevel=2)
-        fulldata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(fulldata[38:53, 3:48], ssdata)
+        actual = self.j2k.read(area=(150, 10, 210, 190), rlevel=2)
+        expected = self.j2k_quarter_data[38:53, 3:48]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_95_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(80, 100, 150, 200), rlevel=2)
-        fulldata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(fulldata[20:38, 25:50], ssdata)
+        actual = self.j2k.read(area=(80, 100, 150, 200), rlevel=2)
+        expected = self.j2k_quarter_data[20:38, 25:50]
+        np.testing.assert_array_equal(actual, expected)
 
     def test_NR_DEC_p0_04_j2k_96_decode(self):
-        jfile = opj_data_file('input/conformance/p0_04.j2k')
-        jp2k = Jp2k(jfile)
-        ssdata = jp2k.read(area=(20, 150, 50, 200), rlevel=2)
-        fulldata = jp2k.read(rlevel=2)
-        np.testing.assert_array_equal(fulldata[5:13, 38:50], ssdata)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        actual = self.j2k.read(area=(20, 150, 50, 200), rlevel=2)
+        expected = self.j2k_quarter_data[5:13, 38:50]
+        np.testing.assert_array_equal(actual, expected)
